pub enum SerializerKind {
MessagePack,
Json,
}Expand description
Serializer kind for checkpoint data
An enum-dispatched serializer that can be stored in checkpoint savers without
requiring dynamic dispatch. Defaults to MessagePack.
Variants
MessagePack
MessagePack binary format (default, high performance)
Json
JSON text format (human readable, debug friendly)
Implementations
Sourceimpl SerializerKind
impl SerializerKind
Sourcepub fn serialize<T: Serialize>(
&self,
value: &T,
) -> Result<Vec<u8>, CheckpointError>
pub fn serialize<T: Serialize>( &self, value: &T, ) -> Result<Vec<u8>, CheckpointError>
Serialize a serializable value to bytes using this serializer
Errors
Returns CheckpointError::Serialize if serialization fails.
Sourcepub fn deserialize<T: DeserializeOwned>(
&self,
data: &[u8],
) -> Result<T, CheckpointError>
pub fn deserialize<T: DeserializeOwned>( &self, data: &[u8], ) -> Result<T, CheckpointError>
Deserialize bytes to a deserializable type using this serializer
Errors
Returns CheckpointError::Deserialize if deserialization fails.
Sourcepub const fn format(&self) -> SerializationFormat
pub const fn format(&self) -> SerializationFormat
Get the format identifier